@@ -164,6 +164,20 @@ def update_annot(pdbaa_fasta_path, out_path=None, past_df=None, num_cpu=1):
                 pharm_class = other_pharm_name
             df.at[index, pharm_class_col] = pharm_class
 
+        for index in list(df.index.values):
+
+            pharm_site = df.at[index, pharm_lig_site_col]
+            match_class = df.at[index, pharm_lig_match_col]
+
+            if pharm_site in [sp2_name, sp12_name]:
+                match_class = f"{pharm_site}.{match_class}"
+            elif pharm_site == none_pharm_name:
+                match_class = none_pharm_name
+            else:
+                match_class = other_pharm_name
+
+            df.at[index, match_class_col] = match_class
+
         df[gene_class_col] = df[prot_col].map(gene_class_dict)
         df[nuc_class_col] = df[bio_lig_col].map(nuc_class_dict).fillna(gtp_name)
 
